@@ -291,7 +291,8 @@ class QGConnector:
                     curl_call.insert(len(curl_call)-1, i)
             logger.debug('curl_call =\n%s' % (str(curl_call)))
             print 'curl_call =\n%s' % (str(curl_call))
-            p = subprocess.call(curl_call)
+            p = subprocess.Popen(curl_call)
+            p.wait()
             out, err = p.communicate()
             request = str(out)
             logger.debug('response text =\n%s' % (str(request)))
